@@ -13,7 +13,20 @@ sub call{
     if(defined $post_api){
         $client->on(all_event => sub{
             my($client,$event,@args) =@_;
-            if($event =~ /^new_group|lose_group|new_friend|lose_friend|new_group_member|lose_group_member$/){
+            if($event eq  'login'){
+                my $post_json = {};
+                $post_json->{post_type} = "event";
+                $post_json->{event} = $event;
+                $post_json->{params} = [@args];
+                my($data,$ua,$tx) = $client->http_post($post_api,json=>$post_json);
+                if($tx->success){
+                    $client->debug("插件[".__PACKAGE__ ."]事件[".$event . "](@args)上报成功");
+                }
+                else{
+                    $client->warn("插件[".__PACKAGE__ . "]事件[".$event."](@args)上报失败:" . encode("utf8",$tx->error->{message}));
+                } 
+            }
+            elsif($event =~ /^new_group|lose_group|new_friend|lose_friend|new_group_member|lose_group_member$/){
                 my $post_json = {};
                 $post_json->{post_type} = "event";
                 $post_json->{event} = $event;
@@ -471,6 +484,35 @@ sub call{
         else{$c->render(json=>{code=>100,status=>"object not found"});}
 
     };
+    any [qw(GET POST)] => '/openwx/make_friend' => sub{
+        my $c = shift;
+        #my($id,$account,$displayname,$markname)= map {defined $_?Encode::encode("utf8",$_):$_} ($c->param("id"),$c->param("account"),$c->param("displayname"),$c->param("markname"));
+        my($id,$verify)= map {defined $_?Encode::encode("utf8",$_):$_} ($c->param("id"),$c->param("verify"));
+        my $object;
+        if($id eq $client->user->id){
+            $c->render(json=>{code=>101,status=>"can not be yourself"});
+            return;
+        }
+        if(defined $client->search_friend(id=>$id)){
+            $c->render(json=>{code=>101,status=>"already a friend"});
+            return;
+        }
+        for my $group ($client->groups){
+            $object = $group->search_group_member(id=>$id,); 
+            last if defined $object;
+        }
+        if(not defined $object){
+            $c->render(json=>{code=>100,status=>"object not found"});
+            return;
+        }
+
+        if($object->make_friend($verify || '')){
+            $c->render(json=>{code=>0,status=>"success"});
+        }
+        else{
+            $c->render(json=>{code=>201,status=>"failure"});
+        }
+    };
     any '/*whatever'  => sub{whatever=>'',$_[0]->render(text=>"api not found",status=>403)};
     package Mojo::Weixin::Plugin::Openwx;
     $server = Mojo::Weixin::Server->new();   
