@@ -62,12 +62,8 @@ sub _http_request{
             }
             $self->save_cookie();
             if(defined $tx and $tx->success){
-                my $r = eval{$opt{json}?$tx->res->json:$tx->res->body;};
-                if($@){
-                    $self->warn($@);
-                    $cb->(undef,$ua,$tx);
-                }
-                else{$cb->($r,$ua,$tx);}
+                my $r = $opt{json}?$self->decode_json($tx->res->body):$tx->res->body;
+                $cb->($r,$ua,$tx);
             }
             elsif(defined $tx){
                 $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code}||"-") . " " . encode("utf8",$tx->error->{message}));
@@ -92,14 +88,8 @@ sub _http_request{
             }
             $self->save_cookie();
             if(defined $tx and $tx->success){
-                my $r = eval{$opt{json}?$tx->res->json:$tx->res->body;};
-                if($@){
-                    $self->warn($@);
-                    next;
-                }
-                else{
-                    return wantarray?($r,$self->ua,$tx):$r;
-                }
+                my $r = $opt{json}?$self->decode_json($tx->res->body):$tx->res->body;
+                return wantarray?($r,$self->ua,$tx):$r;
             }
             elsif(defined $tx){
                 $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code} || "-") . " " . encode("utf8",$tx->error->{message}));
@@ -122,6 +112,9 @@ sub load_cookie{
         $self->warn("客户端加载cookie失败: $@");
         return;
     }
+    else{
+        $self->info("客户端加载cookie[ $cookie_path ]");
+    }
     $self->ua->cookie_jar($cookie_jar);
 
 }
